@@ -104,7 +104,7 @@ export class DocPage {
      * Render the documentation application page
      */
     render() {
-        // Update hash parameters
+        // Decode and validate hash parameters
         try {
             const oldParams = this.params;
             this.updateParams();
@@ -252,7 +252,7 @@ export class DocPage {
                 {'html': 'h2', 'elem': {'text': group}},
                 {
                     'html': 'ul',
-                    'attr': {'class': 'chisel-request-list'},
+                    'attr': {'class': 'chisel-index-list'},
                     'elem': {'html': 'li', 'elem': {'html': 'ul', 'elem': index.groups[group].sort().map(
                         (name) => ({
                             'html': 'li',
@@ -288,6 +288,8 @@ export class DocPage {
         }
         const filteredTypes =
               Object.entries(referencedTypes).sort().filter(([name]) => !typesFilter.includes(name)).map(([, type]) => type);
+        const indexParams = {...this.params};
+        delete indexParams.name;
 
         return [
             // Navigation bar
@@ -295,7 +297,7 @@ export class DocPage {
                 'html': 'p',
                 'elem': {
                     'html': 'a',
-                    'attr': {'href': chisel.href({...this.params, 'name': null})},
+                    'attr': {'href': chisel.href(indexParams)},
                     'elem': {'text': 'Back to documentation index'}
                 }
             },
